==> 0.2.0.tar.gz: test/src/models/env_var_test.dart <==
import 'dart:convert';

import 'package:flavored_env/src/models/env_var.dart';
import 'package:test/expect.dart';
import 'package:test/scaffolding.dart';
import 'package:yaml/yaml.dart';

void main() {
  group('EnvVar', () {
    test('create with empty map', () {
      final EnvVar envVar = EnvVar.fromYamlMap('MY_KEY_NAME', YamlMap());
      expect(envVar.name, 'MY_KEY_NAME');
      expect(envVar.info, isEmpty);
      expect(envVar.value, isEmpty);
      expect(envVar.valueType, String);
      expect(envVar.toDart, '\n\t// \nstatic String myKeyName="";');
      expect(envVar.toEnv, '\n# \nMY_KEY_NAME=');
    });

    test('create with null map', () {
      final EnvVar envVar = EnvVar.fromYamlMap('name', null);
      expect(envVar.name, 'name');
      expect(envVar.info, isEmpty);
      expect(envVar.value, isEmpty);
      expect(envVar.valueType, String);
      expect(envVar.toDart, '\n\t// \nstatic String name="";');
      expect(envVar.toEnv, '\n# \nNAME=');
    });

    test('create with boolean key', () {
      final YamlMap yaml = loadYaml(
        const JsonEncoder.withIndent('  ').convert({
          'info': 'information',
          'value': true,
        }),
      ) as YamlMap;

      final EnvVar envVar = EnvVar.fromYamlMap('name', yaml);
      expect(envVar.name, 'name');
      expect(envVar.info, 'information');
      expect(envVar.value, true);
      expect(envVar.valueType, bool);
      expect(envVar.toDart, '\n\t// information\nstatic bool name=true;');
      expect(envVar.toEnv, '\n# information\nNAME=true');
    });

    test('create with date key', () {
      final YamlMap yaml = loadYaml(
        const JsonEncoder.withIndent('  ').convert({
          'info': 'information',
          'value': '12/6/2022',
        }),
      ) as YamlMap;

      final EnvVar envVar = EnvVar.fromYamlMap('name', yaml);
      expect(envVar.name, 'name');
      expect(envVar.info, 'information');
      expect(envVar.value, '12/6/2022');
      expect(envVar.valueType, String);
      expect(
        envVar.toDart,
        '\n\t// information\nstatic String name="12/6/2022";',
      );
      expect(envVar.toEnv, '\n# information\nNAME=12/6/2022');
    });

    test('create with integer key', () {
      final YamlMap yaml = loadYaml(
        const JsonEncoder.withIndent('  ').convert({
          'info': 'information',
          'value': 999,
        }),
      ) as YamlMap;

      final EnvVar envVar = EnvVar.fromYamlMap('name', yaml);
      expect(envVar.name, 'name');
      expect(envVar.info, 'information');
      expect(envVar.value, 999);
      expect(envVar.valueType, int);
      expect(envVar.toDart, '\n\t// information\nstatic int name=999;');
      expect(envVar.toEnv, '\n# information\nNAME=999');
    });

    test('create with double key', () {
      final YamlMap yaml = loadYaml(
        const JsonEncoder.withIndent('  ').convert({
          'info': 'information',
          'value': 999.1,
        }),
      ) as YamlMap;

      final EnvVar envVar = EnvVar.fromYamlMap('name', yaml);
      expect(envVar.name, 'name');
      expect(envVar.info, 'information');
      expect(envVar.value, 999.1);
      expect(envVar.valueType, double);
      expect(envVar.toDart, '\n\t// information\nstatic double name=999.1;');
      expect(envVar.toEnv, '\n# information\nNAME=999.1');
    });
  });
}

==> 0.4.0.tar.gz: test/src/models/env_var_test.dart <==
import 'dart:convert';

import 'package:flavored_env/src/models/env_var.dart';
import 'package:test/expect.dart';
import 'package:test/scaffolding.dart';
import 'package:yaml/yaml.dart';

void main() {
  group('EnvVar', () {
    test('create with empty map', () {
      final EnvVar envVar = EnvVar.fromYamlMap('MY_KEY_NAME', YamlMap());
      expect(envVar.name, 'MY_KEY_NAME');
      expect(envVar.info, isEmpty);
      expect(envVar.value, isEmpty);
      expect(envVar.valueType, String);
      expect(envVar.toDart, "\n\t// \nString get myKeyName => '';");
      expect(envVar.toEnv, '\n# \nMY_KEY_NAME=');
    });

    test('create with null map', () {
      final EnvVar envVar = EnvVar.fromYamlMap('name', null);
      expect(envVar.name, 'name');
      expect(envVar.info, isEmpty);
      expect(envVar.value, isEmpty);
      expect(envVar.valueType, String);
      expect(envVar.toDart, "\n\t// \nString get name => '';");
      expect(envVar.toEnv, '\n# \nNAME=');
    });

    test('create with boolean key', () {
      final YamlMap yaml = loadYaml(
        const JsonEncoder.withIndent('  ').convert({
          'info': 'information',
          'value': true,
        }),
      ) as YamlMap;

      final EnvVar envVar = EnvVar.fromYamlMap('name', yaml);
      expect(envVar.name, 'name');
      expect(envVar.info, 'information');
      expect(envVar.value, true);
      expect(envVar.valueType, bool);
      expect(envVar.toDart, '\n\t// information\nbool get name => true;');
      expect(envVar.toEnv, '\n# information\nNAME=true');
    });

    test('create with date key', () {
      final YamlMap yaml = loadYaml(
        const JsonEncoder.withIndent('  ').convert({
          'info': 'information',
          'value': '12/6/2022',
        }),
      ) as YamlMap;

      final EnvVar envVar = EnvVar.fromYamlMap('name', yaml);
      expect(envVar.name, 'name');
      expect(envVar.info, 'information');
      expect(envVar.value, '12/6/2022');
      expect(envVar.valueType, String);
      expect(
        envVar.toDart,
        "\n\t// information\nString get name => '12/6/2022';",
      );
      expect(envVar.toEnv, '\n# information\nNAME=12/6/2022');
    });

    test('create with integer key', () {
      final YamlMap yaml = loadYaml(
        const JsonEncoder.withIndent('  ').convert({
          'info': 'information',
          'value': 999,
        }),
      ) as YamlMap;

      final EnvVar envVar = EnvVar.fromYamlMap('name', yaml);
      expect(envVar.name, 'name');
      expect(envVar.info, 'information');
      expect(envVar.value, 999);
      expect(envVar.valueType, int);
      expect(envVar.toDart, '\n\t// information\nint get name => 999;');
      expect(envVar.toEnv, '\n# information\nNAME=999');
    });

    test('create with double key', () {
      final YamlMap yaml = loadYaml(
        const JsonEncoder.withIndent('  ').convert({
          'info': 'information',
          'value': 999.1,
        }),
      ) as YamlMap;

      final EnvVar envVar = EnvVar.fromYamlMap('name', yaml);
      expect(envVar.name, 'name');
      expect(envVar.info, 'information');
      expect(envVar.value, 999.1);
      expect(envVar.valueType, double);
      expect(envVar.toDart, '\n\t// information\ndouble get name => 999.1;');
      expect(envVar.toEnv, '\n# information\nNAME=999.1');
    });
  });
}
